/* -*- c++ -*- */
/*
 * Copyright (c) 2025 Satlab A/S <satlab@satlab.com>
 *
 * This is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 *
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifndef INCLUDED_SATLAB_SWEEPING_MIXER_H
#define INCLUDED_SATLAB_SWEEPING_MIXER_H

#include <gnuradio/blocks/api.h>
#include <gnuradio/sync_block.h>

namespace gr {
namespace satlab {

class BLOCKS_API sweeping_mixer : virtual public sync_block
{
public:
    typedef std::shared_ptr<sweeping_mixer> sptr;

    /*!
     * \brief Sweeping mixer
     *
     * \param sampling_rate sampling rate (Hz)
     */
    static sptr make(double sampling_rate);

    virtual void set_sweep(double start, double stop, double rate) = 0;
    virtual void set_frequency(double frequency) = 0;
    virtual double get_frequency() = 0;

};

} /* namespace satlab */
} /* namespace gr */

#endif /* INCLUDED_SATLAB_SWEEPING_MIXER_CD_H */
