/* 
 * Copyright (c) 2021 Satlab A/S <satlab@satlab.com>
 * 
 * This is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <endian.h>
#include <gnuradio/io_signature.h>
#include "srs3_oid_drop_impl.h"

extern "C" {
#include "spaceframe.h"
}

namespace gr {
    namespace satlab {
        srs3_oid_drop::sptr srs3_oid_drop::make()
        {
            return gnuradio::make_block_sptr<srs3_oid_drop_impl>();
        }

        void srs3_oid_drop_impl::check(pmt::pmt_t pdu)
        {
            const auto vector = pmt::cdr(pdu);
            const auto data = reinterpret_cast<const uint8_t*>(pmt::blob_data(vector));
            const auto length = pmt::blob_length(vector);

            /* Check if frame contains all-zero data (OID/idle frame) */
            bool oid = true;
            for (int i = 0; i < length; i++) {
                if (data[i] != 0x00) {
                    oid = false;
                    break;
                }
            }

            /* Drop OID frames */
            if (oid)
                return;

            message_port_pub(pmt::mp("output"), pdu);
        }

        srs3_oid_drop_impl::srs3_oid_drop_impl()
            : gr::block("srs3_oid_drop",
              gr::io_signature::make(0, 0, 0),
              gr::io_signature::make(0, 0, 0))
        {
            message_port_register_out(pmt::mp("output"));
            message_port_register_in(pmt::mp("check"));
            set_msg_handler(pmt::mp("check"), [this](pmt::pmt_t msg) {
                this->check(msg);
            });
        }

        srs3_oid_drop_impl::~srs3_oid_drop_impl()
        {
        }
    } /* namespace satlab */
} /* namespace gr */

