/* 
 * Copyright (c) 2024 Satlab A/S <satlab@satlab.com>
 * 
 * This is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 3, or (at your option)
 * any later version.
 * 
 * This software is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this software; see the file COPYING.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street,
 * Boston, MA 02110-1301, USA.
 */

#ifdef HAVE_CONFIG_H
#include "config.h"
#endif

#include <gnuradio/io_signature.h>
#include <volk/volk.h>
#include "sub_mov_offset_impl.h"

namespace gr {
  namespace satlab {

    sub_mov_offset::sptr
    sub_mov_offset::make(unsigned int window_size)
    {
      return gnuradio::make_block_sptr
        <sub_mov_offset_impl>(window_size);
    }

    int sub_mov_offset_impl::work(int noutput_items,
                                 gr_vector_const_void_star& input_items,
                                 gr_vector_void_star& output_items)
    {
        float* iptr = (float*)input_items[0];
        float* optr = (float*)output_items[0];

        for (int i = 0; i < noutput_items; i++) {
            const auto [min, max] = std::minmax_element(&iptr[i], &iptr[i + d_window_size]);
            const auto offset = (*min + *max) / 2;
            optr[i] = iptr[i + d_window_size - 1] - offset;
        }

        return noutput_items;
    }

    sub_mov_offset_impl::sub_mov_offset_impl(unsigned int window_size)
      : gr::sync_block("sub_mov_offset",
              gr::io_signature::make(1, 1, sizeof(float)),
              gr::io_signature::make(1, 1, sizeof(float))),
        d_window_size(window_size)
    {
        this->set_history(window_size);
    }
  } /* namespace satlab */
} /* namespace gr */
