/* -*- c++ -*- */
/*
 * Copyright 2013 Free Software Foundation, Inc.
 *
 * This file is part of GNU Radio
 *
 * SPDX-License-Identifier: GPL-3.0-or-later
 *
 */

#ifndef INCLUDED_SATLAB_SWEEPING_MIXER_IMPL_H
#define INCLUDED_SATLAB_SWEEPING_MIXER_IMPL_H

#include <gnuradio/io_signature.h>
#include <gnuradio/satlab/api.h>
#include <gnuradio/satlab/sweeping_mixer.h>
#include <gnuradio/nco.h>

namespace gr {
namespace satlab {

class sweeping_mixer_impl : public sweeping_mixer
{
private:
    const double d_sampling_rate;

    double d_freq_start;
    double d_freq_stop;
    double d_freq_step;

    gr::thread::mutex d_mutex;
    gr::nco<gr_complex, double> d_nco;

public:
    sweeping_mixer_impl(double sampling_rate);
    ~sweeping_mixer_impl() override;
    void set_sweep(double start, double stop, double rate) override;
    void set_frequency(double frequency) override;
    double get_frequency() override;

    int work(int noutput_items,
             gr_vector_const_void_star& input_items,
             gr_vector_void_star& output_items) override;
};

} /* namespace blocks */
} /* namespace gr */

#endif /* INCLUDED_SATLAB_SWEEPING_MIXER_IMPL_H */
